'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _fs = require('fs');

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _genericNames = require('generic-names');

var _genericNames2 = _interopRequireDefault(_genericNames);

var _postcssModulesExtractImports = require('postcss-modules-extract-imports');

var _postcssModulesExtractImports2 = _interopRequireDefault(_postcssModulesExtractImports);

var _postcssModulesLocalByDefault = require('postcss-modules-local-by-default');

var _postcssModulesLocalByDefault2 = _interopRequireDefault(_postcssModulesLocalByDefault);

var _postcssModulesParser = require('postcss-modules-parser');

var _postcssModulesParser2 = _interopRequireDefault(_postcssModulesParser);

var _postcssModulesScope = require('postcss-modules-scope');

var _postcssModulesScope2 = _interopRequireDefault(_postcssModulesScope);

var _postcssModulesValues = require('postcss-modules-values');

var _postcssModulesValues2 = _interopRequireDefault(_postcssModulesValues);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const writeCssFile = (filename, content) => {
  _mkdirp2.default.sync((0, _path.dirname)(filename));
  (0, _fs.writeFileSync)(filename, content);
};

const appendCssFile = (filename, content) => {
  _mkdirp2.default.sync((0, _path.dirname)(filename));
  (0, _fs.appendFileSync)(filename, content);
};

let hasWrite = false;
const cssSourceFilePathArr = [];

const wirteCssToFile = (path, lazyResult) => {
  const correspondingMapPath = `${path}.map`;

  if (!hasWrite) {
    writeCssFile(path, lazyResult.css);

    if (lazyResult.map) {
      writeCssFile(correspondingMapPath, lazyResult.map);
    }

    hasWrite = true;
  } else {
    appendCssFile(path, lazyResult.css);

    if (lazyResult.map) {
      appendCssFile(correspondingMapPath, lazyResult.map);
    }
  }
};

const getTokens = (runner, cssSourceFilePath, filetypes, extractCssOpts) => {
  const extension = cssSourceFilePath.substr(cssSourceFilePath.lastIndexOf('.'));
  const syntax = filetypes[extension];

  const options = {
    from: cssSourceFilePath
  };

  if (syntax) {
    // eslint-disable-next-line import/no-dynamic-require, global-require
    options.syntax = require(syntax);
  }

  const lazyResult = runner.process((0, _fs.readFileSync)(cssSourceFilePath, 'utf-8'), options);

  // only if the css which we import doesn't be written before,we wirte it to the file
  if (cssSourceFilePathArr.indexOf(cssSourceFilePath) === -1 && extractCssOpts) {
    if (extractCssOpts.to) {
      const toPath = extractCssOpts.to;

      wirteCssToFile((0, _path.resolve)(process.cwd(), `../../${toPath}`), lazyResult);
    } else if (extractCssOpts.stayInOwnComponent) {
      const filename = (0, _path.basename)(cssSourceFilePath);

      wirteCssToFile((0, _path.resolve)(cssSourceFilePath, `../cssModule/${filename}`), lazyResult);
    }
  }

  lazyResult.warnings().forEach(message => {
    // eslint-disable-next-line no-console
    console.warn(message.text);
  });

  // after write css to the file,we push the path to the array to avoid we write the same css repeatedly
  cssSourceFilePathArr.push(cssSourceFilePath);

  return lazyResult.root.tokens;
};

exports.default = (cssSourceFilePath, options) => {
  // eslint-disable-next-line prefer-const
  let runner;

  const scopedName = (0, _genericNames2.default)(options.generateScopedName || '[path]___[name]__[local]___[hash:base64:5]', {
    context: options.context || process.cwd()
  });

  const fetch = (to, from) => {
    const fromDirectoryPath = (0, _path.dirname)(from);
    const toPath = (0, _path.resolve)(fromDirectoryPath, to);

    return getTokens(runner, toPath, options.filetypes, options.extractCss);
  };

  const plugins = [_postcssModulesValues2.default, _postcssModulesLocalByDefault2.default, _postcssModulesExtractImports2.default, new _postcssModulesScope2.default({
    generateScopedName: scopedName
  }), new _postcssModulesParser2.default({
    fetch
  })];

  runner = (0, _postcss2.default)(plugins);

  return getTokens(runner, cssSourceFilePath, options.filetypes, options.extractCss);
};
//# sourceMappingURL=requireCssModule.js.map